 <!-- begin forms_button -->
{% if document_status == COMPLETE %}
<a id="{{ btn_id }}" role="button" class="btn btn-sm {{ btn_color }}" href="{{ href }}">
	<i class="{{ fa_icon }} fa-sm" aria-hidden="true"></i> {{ label }}{% if label_fa_icon %} <i class="{{ label_fa_icon }}"></i>{% endif %}
</a>
{% endif %}
<!-- end forms_button -->
