{% if show_button %}
    {% if wrapped_appointment.appt_status == INCOMPLETE_APPT or wrapped_appointment.appt_status == COMPLETE_APPT %}
        <a id="{{ anchor_id }}" role="button" class="btn btn-sm btn-default"
           {% if wrapped_appointment.object.site.id != request.site.id %} disabled {% endif %}
           href="{{ href }}">
            <i class="fas fa-calendar-plus fa-lg" data-toggle="tooltip" title="Add continuation / unscheduled appointment" aria-hidden="true"></i>
        </a>
    {% endif %}
{% endif %}

