{% if consents %}

<table class="table table-condensed">
    <thead></thead>
    <tbody>
    	{% for consent in consents %}
	        <tr>
	        <td class="{% if consent %}default{% else %}warning{% endif %}">
		        {% with wrapped=consent %}
		            {% include 'edc_dashboard/bootstrap3/controls/change_button.html' %}
		        {% endwith %}
			</td>
	        <td class="{% if consent %}default{% else %}warning{% endif %}">
	            <span class="h6">{{ consent.verbose_name|title }}&nbsp;v{{ consent.version }}
	           	<span class="text text-muted">consented {{ consent.object.consent_datetime|date:"SHORT_DATE_FORMAT"}}</span>
	           </span>
	        </td>
	      	</tr>
      	{% endfor %}
    </tbody>
</table>

{% endif %}