<a id="{{ anchor_id }}" role="button" class="btn btn-sm btn-default"
   {{ disabled }} href="{{ href }}"  data-toggle="tooltip"  title="{{ title }}">
    <i class="fas fa-pencil-alt fa-fw" aria-hidden="true"></i> Appt
</a>
